==> interweave-emoji-picker-6.0.2.tgz: package/README.md <==
# Interweave Emoji Picker

[![Build Status](https://github.com/milesj/interweave/workflows/Build/badge.svg)](https://github.com/milesj/interweave/actions?query=branch%3Amaster)
[![npm version](https://badge.fury.io/js/interweave-emoji-picker.svg)](https://www.npmjs.com/package/interweave-emoji-picker)
[![npm deps](https://david-dm.org/milesj/interweave.svg?path=packages/emoji-picker)](https://www.npmjs.com/package/interweave-emoji-picker)

A React based emoji picker powered by [Interweave][interweave] and [Emojibase][emojibase]. Supports
the following features:

- Customizable theme, styles, and icons.
- Configurable element and render order.
- Localized emoji annotations.
- Emoji grouping and categorization.
- Multi-word deep search.
- Skin tone palette selector.
- Enlarged preview on hover.
- Emoticons and shortcodes.
- Recently and frequently used.
- Virtualized rendering.
- And much more!

<img src="https://raw.githubusercontent.com/milesj/interweave/master/website/static/img/slack.png" height="350">
<img src="https://raw.githubusercontent.com/milesj/interweave/master/website/static/img/twitter.png" height="350">

## Requirements

- [Interweave][interweave]
- [Emojibase][emojibase]

## Installation

```
yarn add interweave interweave-emoji interweave-emoji-picker emojibase
// Or
npm install interweave interweave-emoji interweave-emoji-picker emojibase
```

## Documentation

[https://interweave.dev/docs/exts/emoji-picker](https://interweave.dev/docs/exts/emoji-picker)

[interweave]: https://interweave.dev
[emojibase]: https://emojibase.dev

==> interweave-emoji-picker-7.0.0.tgz: package/README.md <==
# Interweave Emoji Picker

[![Build Status](https://github.com/milesj/interweave/workflows/Build/badge.svg)](https://github.com/milesj/interweave/actions?query=branch%3Amaster)
[![npm version](https://badge.fury.io/js/interweave-emoji-picker.svg)](https://www.npmjs.com/package/interweave-emoji-picker)
[![npm deps](https://david-dm.org/milesj/interweave.svg?path=packages/emoji-picker)](https://www.npmjs.com/package/interweave-emoji-picker)

A React based emoji picker powered by [Interweave][interweave] and [Emojibase][emojibase]. Supports
the following features:

- Customizable theme, styles, and icons.
- Configurable element and render order.
- Localized emoji labels and annotations.
- Emoji grouping and categorization.
- Multi-word deep search.
- Skin tone palette selector.
- Enlarged preview on hover.
- Emoticons and shortcodes.
- Recently and frequently used.
- Virtualized rendering.
- And much more!

<img src="https://raw.githubusercontent.com/milesj/interweave/master/website/static/img/slack.png" height="350" />
<img src="https://raw.githubusercontent.com/milesj/interweave/master/website/static/img/twitter.png" height="350" />

## Requirements

- [Interweave][interweave]
- [Emojibase][emojibase]

## Installation

```
yarn add interweave interweave-emoji interweave-emoji-picker emojibase
// Or
npm install interweave interweave-emoji interweave-emoji-picker emojibase
```

## Documentation

[https://interweave.dev/docs/exts/emoji-picker](https://interweave.dev/docs/exts/emoji-picker)

[interweave]: https://interweave.dev
[emojibase]: https://emojibase.dev
